@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
 our $DATE = '2017-01-12'; # DATE
-our $VERSION = '0.46'; # VERSION
+our $VERSION = '0.47'; # VERSION
 
 use 5.010001;
 use strict;
@@ -121,7 +121,7 @@ sub _gen_read_config {
     push @l2, '    subcommand_name    => $_pci_r->{subcommand_name},', "\n";
     push @l2, '    config_profile     => $_pci_r->{config_profile},', "\n";
     push @l2, '    common_opts        => {},', "\n"; # XXX so currently we can't set e.g. format or
-    push @l2, '    meta               => $_pci_metas{ $_pci_r->{subcommand_name} },', "\n";
+    push @l2, '    meta               => $_pci_metas->{ $_pci_r->{subcommand_name} },', "\n";
     push @l2, '    meta_is_normalized => 1,', "\n";
     push @l2, '  );', "\n";
     push @l2, '  die $res unless $res->[0] == 200;', "\n";
@@ -1338,16 +1338,16 @@ _
                 JSON::MaybeXS::encode_json(\%tmp);
             }, "\n\n",
 
-            'my %_pci_metas = %{ ', do {
+            'my $_pci_metas = ', do {
                 local $Data::Dmp::OPT_DEPARSE=0;
                 dmp($cd->{metas});
-            }, " };\n\n",
+            }, ";\n\n",
 
             "# This script is generated by ", __PACKAGE__,
             " version ", (${__PACKAGE__."::VERSION"} // 'dev'), " on ",
             scalar(localtime), ".\n\n",
 
-            (keys %{$cd->{mods}} ? "# Rinci metadata taken from these modules: ".join(", ", map {"$_ ".$cd->{mods}{$_}{version}} sort keys %{$cd->{mods}})."\n\n" : ""),
+            (keys %{$cd->{mods}} ? "# Rinci metadata taken from these modules: ".join(", ", map {"$_ ".($cd->{mods}{$_}{version} // "(no version)")} sort keys %{$cd->{mods}})."\n\n" : ""),
 
             "# You probably should not manually edit this file.\n\n",
 
@@ -1445,7 +1445,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.46 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2017-01-12.
+This document describes version 0.47 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2017-01-12.
 
 =head1 SYNOPSIS
 
